@@ -101,7 +101,10 @@ gboolean gok_page_actions_initialize (GladeXML* xml)
 			/* TODO: persist this list so we can query it later */
 			slist = slist->next;
 		}
-	
+		if (!gok_input_get_extension_device_name() ||
+		    !strlen(gok_input_get_extension_device_name())) {
+		         items = g_list_prepend (items, "");
+		}
 		gtk_combo_set_popdown_strings (GTK_COMBO (pComboBox), items);
 		g_list_free (items);
 	}
@@ -448,8 +451,7 @@ void gok_page_actions_button_clicked_change_name ()
 				{
 					/* yes the name was changed */
 					g_free (m_pActionCurrent->pDisplayName);
-					m_pActionCurrent->pDisplayName = (gchar*)g_malloc (strlen (pNewName) + 1);
-					strcpy (m_pActionCurrent->pDisplayName, pNewName);
+					m_pActionCurrent->pDisplayName = g_strdup (pNewName);
 		
 					/* add the new name to the combo box list */
 					gok_page_actions_fill_combo_action_names();
@@ -475,8 +477,8 @@ void gok_page_actions_button_clicked_new ()
 {
 	GokAction* pActionNew;
 	int count;
-	gchar bufferName[200];
-	gchar bufferDisplayName[200];
+	gchar *bufferName;
+	gchar *bufferDisplayName;
 	
 	g_assert (m_pActionCurrent != NULL);
 	
@@ -484,20 +486,20 @@ void gok_page_actions_button_clicked_new ()
 	/* it will be something like "new action 1" */
 	for (count = 1; count < 100; count++)
 	{
-		sprintf (bufferDisplayName, _("New Action %d"), count);
-		sprintf (bufferName, "new_action_%d", count);
+		bufferDisplayName = g_strdup_printf (_("New Action %d"), count);
+		bufferName = g_strdup_printf ("new_action_%d", count);
 		if ((gok_action_find_action (bufferDisplayName, TRUE) == NULL) &&
 			(gok_action_find_action (bufferName, FALSE) == NULL))
 		{
 			break;
 		}
+		g_free (bufferDisplayName);
+		g_free (bufferName);
 	}
 	
 	pActionNew = gok_action_new();
-	pActionNew->pName = (gchar*)g_malloc (strlen (bufferName) + 1);
-	strcpy (pActionNew->pName, bufferName);
-	pActionNew->pDisplayName = (gchar*)g_malloc (strlen (bufferDisplayName) + 1);
-	strcpy (pActionNew->pDisplayName, bufferDisplayName);
+	pActionNew->pName = bufferName;
+	pActionNew->pDisplayName = bufferDisplayName;
 	
 	/* make the new action the same as the current action */
 	if (m_pActionCurrent != NULL)
@@ -719,7 +721,7 @@ void gok_page_actions_input_device_changed (GtkEditable* pEditControl)
 	if (pStrComboInputDeviceName && strlen (pStrComboInputDeviceName) == 0) {
 		g_free (pStrComboInputDeviceName);
 	}
-	else
+	else if (pStrComboInputDeviceName)
 	{
 		/* find the device in our list of input devices */
 	        
