@@ -70,6 +70,7 @@
 
 /*
  * private prototypes
+1;5B
  */
 static void gok_spy_focus_listener (const AccessibleEvent *event,
                                     void *user_data);
@@ -100,7 +101,7 @@ static void gok_spy_object_state_listener (const AccessibleEvent *event,
                                                 void *user_data);
 
 static gboolean gok_spy_is_visible (Accessible *accessible);
-		
+
 static void gok_spy_free_nodes (GSList *nodelist);										
 static void gok_spy_resolve_namesakes (GSList *nodelist);
 
@@ -184,8 +185,6 @@ gok_spy_get_focussed_object (void)
  */
 void gok_spy_accessible_ref(Accessible* accessible)
 {
-	char *s;
-
 	gok_log_enter ();
 
 	if (accessible != NULL)
@@ -193,6 +192,7 @@ void gok_spy_accessible_ref(Accessible* accessible)
 		explicitrefs++;
 		Accessible_ref (accessible);
 #if defined(ENABLE_LOGGING_NORMAL)
+		char *s;
 		s = Accessible_getName (accessible);
 		if (s == NULL)
 		{
@@ -215,14 +215,13 @@ void gok_spy_accessible_ref(Accessible* accessible)
 
 void gok_spy_accessible_implicit_ref(Accessible* accessible)
 {
-	char *s;
-
 	gok_log_enter ();
 
 	if (accessible != NULL)
 	{
 		implicitrefs++;
 #if defined(ENABLE_LOGGING_NORMAL)
+		char *s;
 		s = Accessible_getName (accessible);
 		if (s == NULL)
 		{
@@ -245,13 +244,12 @@ void gok_spy_accessible_implicit_ref(Accessible* accessible)
 
 void gok_spy_accessible_unref(Accessible* accessible)
 {
-	char *s;
-
 	gok_log_enter ();
 
 	if (accessible != NULL)
 	{
 #if defined(ENABLE_LOGGING_NORMAL)
+		char *s;
 		s = Accessible_getName (accessible);
 		if (s == NULL)
 		{
@@ -596,8 +594,7 @@ gok_spy_node_match (AccessibleNode *node, GokSpySearchType type)
 		return node->flags.data.is_ui;
 		break;
 	case GOK_SPY_SEARCH_EDITABLE_TEXT:
-		if (Accessible_isEditableText (node->paccessible))
-			return TRUE;
+		return gok_spy_is_editable (node->paccessible);
 		break;
 	case GOK_SPY_SEARCH_CHILDREN:
 	case GOK_SPY_SEARCH_COMBO:
@@ -653,14 +650,13 @@ gok_spy_get_editable (Accessible *search_root)
 	int child_count = Accessible_getChildCount (search_root);
 	while (i < child_count) 
 	{
-	    AccessibleRole role = SPI_ROLE_INVALID;
 	    child = Accessible_getChildAtIndex (search_root, i);
 	    if (child) 
 	    {
 		gok_spy_accessible_implicit_ref (child);
-		if (Accessible_isEditableText (child)) 
+		if (gok_spy_is_editable (child))
 		{
-		    return child;
+			return child;
 		}
 		else 
 		{
@@ -1120,7 +1116,6 @@ gboolean _gok_spy_handle_gecko_browse_tab_change (Accessible* source)
 gboolean gok_spy_check_queues(void)
 {
 	EventNode* en = NULL;
-	char *s;
 	GokKeyboard *current_kbd;
 
 	gok_log_enter();
@@ -1138,6 +1133,7 @@ gboolean gok_spy_check_queues(void)
 #if defined(ENABLE_LOGGING_NORMAL)
 		if (en && en->event && en->event->source != NULL)
 		{
+			char *s;
 			s = Accessible_getName (en->event->source);
 			if (s == NULL)
 			{
@@ -1272,20 +1268,10 @@ gboolean gok_spy_worth_searching (Accessible* accessible)
 	AccessibleStateSet* ass = NULL;
 
 	gok_log_enter();
-	
-	switch (Accessible_getRole (accessible)) 
-	{
-	case SPI_ROLE_MENU:
-	case SPI_ROLE_MENU_BAR:
-	case SPI_ROLE_MENU_ITEM:
-	case SPI_ROLE_CHECK_MENU_ITEM:
-	case SPI_ROLE_RADIO_MENU_ITEM:
-		bmenu = TRUE;
-		break;
-	default:
-		bmenu = FALSE;
-	}
-	ass = Accessible_getStateSet(accessible);
+
+	bmenu = gok_spy_is_menu_role(Accessible_getRole(accessible));	
+	/* no longer consider SPI_ROLE_MENU_BAR -- to work better with ff3*/
+
 	if (ass != NULL)
 	{
 		/* state heuristic: 
@@ -1326,6 +1312,19 @@ gok_spy_is_visible (Accessible *accessible)
 	return retval;
 }
 
+gboolean
+gok_spy_is_editable (Accessible *accessible)
+{
+	gboolean retval = FALSE;
+	if (accessible && Accessible_isEditableText(accessible)) {
+		AccessibleStateSet *states = Accessible_getStateSet (accessible);
+		if (AccessibleStateSet_contains (states, SPI_STATE_EDITABLE))
+			retval = TRUE;
+		AccessibleStateSet_unref (states);
+	}
+	return retval;
+}
+
 gboolean
 gok_spy_is_menu_role (AccessibleRole role)
 {
@@ -1373,7 +1372,7 @@ gok_spy_is_ui (Accessible *accessible, Accessible *parent, AccessibleRole role)
 		interesting = TRUE;
 		break;
 	default:
-		if (Accessible_isEditableText (accessible) ||
+		if (gok_spy_is_editable (accessible) ||
 		    /*Accessible_isHypertext (accessible) ||*/
 		    Accessible_isTable (accessible) ||
 		    (!gok_spy_is_menu_role (role) && 
@@ -1567,8 +1566,6 @@ GSList* gok_spy_append_node (GSList* nodes,
 			     Accessible* pAccessible,
 			     AccessibleNodeFlags flags)
 {
-	AccessibleNode* pLastNode = NULL;
-	AccessibleNode* pNewNode = NULL;
 	AccessibleRelation** relations = NULL;
 	Accessible* targetAccessible = NULL;
 	AccessibleRole role;
@@ -1862,7 +1859,7 @@ GSList* gok_spy_append_node (GSList* nodes,
 			if (gs) {
 				g_free (gs);
 			}
-			if (Accessible_isEditableText (pAccessible)) {
+			if (gok_spy_is_editable (pAccessible)) {
 				pName = g_strdup ("Text Entry (empty)");
 			}
 		}
@@ -1996,13 +1993,14 @@ GSList* gok_spy_append_node (GSList* nodes,
 	}
 	
     /* We consider it safe enough to provide a name for nameless Selections */
-    if ((pName == NULL) && Accessible_isSelection(pAccessible)) {
+    /* removed for ff3
+	if ((pName == NULL) && Accessible_isSelection(pAccessible)) {
         gchar* rolename;
         rolename = Accessible_getRoleName (pAccessible);
         pName = g_strdup (rolename);
         nodes = gok_spy_add_node (nodes, pAccessible, flags, 0, pName);
         SPI_freeString (rolename);
-    }
+    }*/
 
    
     if ((pName == NULL) && gok_main_get_debug_nameless()) {
@@ -2349,7 +2347,6 @@ gok_spy_button_is_switch_trigger (int button)
 		return FALSE;
 	}
 	else {
-	        gboolean retval;
 		gok_log("gok_data_get_drive_corepointer() is FALSE");
 		return gok_scanner_current_state_uses_core_mouse_button(button);
 	}
@@ -2417,8 +2414,6 @@ gulong gok_spy_get_modmask (void)
  */
 void gok_spy_modifier_listener(const AccessibleEvent *event, void *user_data)
 {
-	const struct gok_modifier_keymask *m;
-       
 	keyboardmods = event->detail2;
 
 	gok_log_enter();
@@ -2511,7 +2506,7 @@ gok_spy_get_active_frame( )
 static gboolean
 gok_spy_find_and_append_toolbar_items (Accessible *root, AccessibleNodeFlags flags)
 {
-	Accessible *child, *tmp;
+	Accessible *child;
 	gint i, nchildren;
 	gboolean retval = FALSE;
 
@@ -2625,7 +2620,7 @@ gok_spy_search_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboar
 				{
 				    ui_flags.data.gui = flags.data.is_ui = TRUE;
 				}
-				if (keyboard_ui_flags.data.editable_text && Accessible_isEditableText (child)) 
+				if (keyboard_ui_flags.data.editable_text && gok_spy_is_editable (child)) 
 				{
 					ui_flags.data.editable_text = TRUE;
 				}
