@@ -1011,7 +1011,6 @@ static char cursor_bits[] = {
 void
 gok_main_set_cursor (GdkCursor *cursor)
 {
-	GdkPixmap *source;
 	GdkColor color = { 0, 0, 0, 0 };
 	static GdkCursor *nilCursor = NULL;
 	if (!cursor) {
@@ -1147,10 +1146,6 @@ void gok_main_window_change_listener (Accessible* pAccessible)
 
 /**
 * gok_main_object_state_listener
-* @pAccessible: Pointer to the foreground window's accessible interface.
-* 
-* This function is called each time the foreground window changes.
-*
 */
 static void 
 gok_main_object_state_listener (Accessible* pAccessible)
@@ -1170,19 +1165,21 @@ gok_main_object_state_listener (Accessible* pAccessible)
 				   is represented properly. TODO: generalize
 				*/
 				ass = Accessible_getStateSet(pAccessible);
-				if (AccessibleStateSet_contains( ass, SPI_STATE_CHECKED )) {
+				if (ass) { 
+				 if (AccessibleStateSet_contains( ass, SPI_STATE_CHECKED )) {
 					pK->ComponentState.active = TRUE;
-				}
-				else {
+				 }
+				 else {
 					pK->ComponentState.active = FALSE;
-				}
-				if (!AccessibleStateSet_contains( ass, SPI_STATE_ENABLED ))
-				{
+				 }
+				 if (!AccessibleStateSet_contains( ass, SPI_STATE_ENABLED ))
+				 {
 					pK->Style = KEYSTYLE_INSENSITIVE;
 					gok_key_set_button_name (pK);
+				 }
+				 AccessibleStateSet_unref(ass);
+				 gok_key_update_toggle_state (pK);
 				}
-				AccessibleStateSet_unref(ass);
-				gok_key_update_toggle_state (pK);
 				/* unfortunately, another special case for now... */
 				if (Accessible_getRole (pAccessible) == SPI_ROLE_PAGE_TAB) 
 				{
@@ -1230,8 +1227,8 @@ static gboolean gok_main_xevie_io (GIOChannel *source,
 				   GIOCondition condition,
 				   gpointer data)
 {
-    XEvent xevie_event;
 #ifdef HAVE_XEVIE
+    XEvent xevie_event;
     while (xevie_dpy && XPending (xevie_dpy)) {
       XMotionEvent *motion_event;
       gboolean has_active_key = gok_scanner_key_is_active ();
@@ -1830,7 +1827,6 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 {
 	GtkWidget *window1;
 	GtkWidget *fixed1;
-	GtkWidget *event1;
 
 	gok_log_enter();
 					
@@ -1842,7 +1838,6 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 				"can_focus", FALSE,
 				"type", GTK_WINDOW_TOPLEVEL,
 				"window-position", GTK_WIN_POS_CENTER,
-				"title","GOK",
 				"allow_grow", TRUE,
 				"allow_shrink", TRUE,
 				"border_width", 0,
@@ -1852,6 +1847,9 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 			     "signal::destroy", on_window1_destroy, NULL,
 			     NULL);
 
+	g_set_application_name (_("GOK"));
+	gtk_window_set_default_icon_name ("gok");
+
 	m_OurResizeWidth = 200;
 	m_OurResizeHeight = 100;
 	gtk_window_set_default_size (GTK_WINDOW (window1), m_OurResizeWidth, m_OurResizeHeight);
@@ -2836,7 +2834,6 @@ gok_main_window_contains_pointer (void)
 {
 	gint x=-1, y=-1, w=0, h=0;
 	gint px, py;
-	GdkModifierType mask;
 	GtkWidget *widget = gok_main_get_main_window ();
 	gok_scanner_get_pointer_location (&px, &py);
 	if (widget->window) {
@@ -3155,8 +3152,6 @@ gok_main_warn (gchar *message, gboolean always, GCallback cancelfunc, GCallback
 	if (always || gok_scanner_current_state_uses_corepointer ()) 
 	{
 		GtkWidget*	button;
-		gint         response_id;
-		gboolean 	returnCode = TRUE;
 
 		if (opt_out && okfunc) (*okfunc) ();
 
@@ -3219,8 +3214,6 @@ gok_main_check_accessibility ()
         
     if (!accessibility_on) {
 		GtkWidget*	button;
-		gint         response_id;
-		gboolean 	returnCode = TRUE;
 		
 		acd = gtk_message_dialog_new (
 			NULL, 
